Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(49)

Unified Diff: remoting/client/chromoting_client.h

Issue 2052723002: Adding an interface to allow extention of the audio player for CRD and iOS. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Adding missing dep on proto for test. Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/client/chromoting_client.h
diff --git a/remoting/client/chromoting_client.h b/remoting/client/chromoting_client.h
index 704a672d7dd227bb086867bea8f12957cd2889b6..443bd6c6882bd4ec32d6be7fda98ff4801abafbb 100644
--- a/remoting/client/chromoting_client.h
+++ b/remoting/client/chromoting_client.h
@@ -12,6 +12,7 @@
#include "base/callback.h"
#include "base/macros.h"
+#include "base/memory/weak_ptr.h"
#include "remoting/protocol/client_authentication_config.h"
#include "remoting/protocol/client_stub.h"
#include "remoting/protocol/clipboard_stub.h"
@@ -36,8 +37,8 @@ class TransportContext;
class VideoRenderer;
} // namespace protocol
+class AudioConsumer;
class AudioDecodeScheduler;
-class AudioPlayer;
class ClientContext;
class ClientUserInterface;
class FrameConsumerProxy;
@@ -47,12 +48,12 @@ class ChromotingClient : public SignalStrategy::Listener,
public protocol::ClientStub {
public:
// |client_context|, |user_interface| and |video_renderer| must outlive the
// client. |audio_player| may be null, in which case audio will not be
// requested.
ChromotingClient(ClientContext* client_context,
ClientUserInterface* user_interface,
protocol::VideoRenderer* video_renderer,
- std::unique_ptr<AudioPlayer> audio_player);
+ base::WeakPtr<AudioConsumer> audio_consumer);
~ChromotingClient() override;
@@ -102,7 +103,7 @@ class ChromotingClient : public SignalStrategy::Listener,
const protocol::TransportRoute& route) override;
private:
- // SignalStrategy::StatusObserver interface.
+ // SignalStrategy::StatusObserver interface.
void OnSignalStrategyStateChange(SignalStrategy::State state) override;
bool OnSignalStrategyIncomingStanza(const buzz::XmlElement* stanza) override;
@@ -47,12 +48,12 @@ class ChromotingClient : public SignalStrategy::Listener,
public:
// |client_context|, |user_interface| and |video_renderer| must outlive the
- // client. |audio_player| may be null, in which case audio will not be
+ // client. |audio_consumer| may be null, in which case audio will not be
// requested.
ChromotingClient(ClientContext* client_context,

Powered by Google App Engine
This is Rietveld 408576698